/* stata do-file for replication of all models in tables 1, 2 and 3 of "Enlargement Processes and Distributional Conflicts: The Politics of Discriminatory Membership in the European Union" by Christina J. Schneider */

/* all variables used are labeled in the stata data set discriminatorymembership_replication.dta */


set mem 10000
set more off
set mat 800

cd c:\        /* specify the working directory where you have put the data set and want to save the results */

use discriminatorymembership_replication.dta

log using discriminatorymembership_replication.log, replace




/* Table 1 provides descriptive statistics*/

sum disat bipn_eu100  expbip concur sizen ceiling majority_per_policy demdisdum prefdependency rivalry contribution polityivnew perccouncil_change freedomofmovement structuralfunds agriculture



/* Models 1 to 3 of table 2 test the main hypothesis of the paper*/

probit disat bipn_eu100  expbip concur sizen ceiling demdisdum, cluster(oldmembers)
probit disat bipn_eu100  expbip concur sizen ceiling majority_per_policy demdisdum prefdependency rivalry contribution polityivnew perccouncil_change, cluster(oldmembers)
probit disat bipn_eu100  expbip concur sizen ceiling demdisdum  freedomofmovement structuralfunds agriculture, cluster(oldmembers)


/* Table 3 presents the conditional effects of model 2*/

probit disat bipn_eu100  expbip concur sizen ceiling demdisdum majority_per_policy prefdependency rivalry contribution polityivnew perccouncil_change, cluster(oldmembers)


/* Share of GDP per Capita as EU average*/

prvalue, x(bipn_eu100=max polityivnew=max  majority_per_policy=1 rivalry=0 concur=0.48 sizen=9) rest(min)
prvalue, x(bipn_eu100=76.2  polityivnew=max  majority_per_policy=1 rivalry=0 concur=0.48 sizen=9) rest(min) 
prvalue, x( bipn_eu100=median  polityivnew=max  majority_per_policy=1 rivalry=0 concur=0.48 sizen=9) rest(min)
prvalue, x(bipn_eu100=40.7 polityivnew=max  majority_per_policy=1 rivalry=0 concur=0.48 sizen=9) rest(min)
prvalue, x( bipn_eu100=min  polityivnew=max  majority_per_policy=1 rivalry=0 concur=0.48 sizen=9) rest(min)

prvalue, x(bipn_eu100=max  expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10  sizen=10 prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08 ) 
prvalue, x( bipn_eu100=76.2 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10  sizen=10 prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08 ) 
prvalue, x( bipn_eu100=median expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10  sizen=10 prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08) 
prvalue, x( bipn_eu100=40.7 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10  sizen=10 prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08) 
prvalue, x( bipn_eu100=min expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10  sizen=10 prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08 ) 

prvalue, x(bipn_eu100=max sizen=12) rest(median)
prvalue, x(bipn_eu100=76.2 sizen=12) rest(median) 
prvalue, x(bipn_eu100=median sizen=12) rest(median)
prvalue, x(bipn_eu100=40.7 sizen=12) rest(median)
prvalue, x(bipn_eu100=min sizen=12) rest(median)

prvalue, x(bipn_eu100=max  expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9  sizen=15 prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15 ) 
prvalue, x( bipn_eu100=76.2 expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9  sizen=15 prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 
prvalue, x( bipn_eu100=median expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9  sizen=15 prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 
prvalue, x( bipn_eu100=40.7 expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9 sizen=15 prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 
prvalue, x( bipn_eu100=min expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9  sizen=15 prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 

prvalue, x(bipn_eu100=max polityivnew=min  concur=0 majority_per_policy=0) rest(max)
prvalue, x(bipn_eu100=76.2  polityivnew=min  concur=0 majority_per_policy=0) rest(max) 
prvalue, x( bipn_eu100=median  polityivnew=min concur=0 majority_per_policy=0) rest(max)
prvalue, x(bipn_eu100=40.7 polityivnew=min  concur=0 majority_per_policy=0) rest(max)
prvalue, x( bipn_eu100=min  polityivnew=min  concur=0 majority_per_policy=0) rest(max)


/*Expected Size of the European Union after Enlargement*/

prvalue, x( sizen=9 bipn_eu100=max polityivnew=max concur=max majority_per_policy=1) rest(min)
prvalue, x( sizen=10 bipn_eu100=max  polityivnew=max concur=max majority_per_policy=1) rest(min) 
prvalue, x(sizen=12 bipn_eu100=max  polityivnew=max concur=max majority_per_policy=1) rest(min)
prvalue, x(sizen=15 bipn_eu100=max polityivnew=max concur=max majority_per_policy=1) rest(min)
prvalue, x( sizen=25 bipn_eu100=max  polityivnew=max concur=max majority_per_policy=1) rest(min)

prvalue, x(sizen=9 bipn_eu100=76.2 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10   prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08 ) 
prvalue, x( sizen=10  bipn_eu100=76.2 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10   prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08 ) 
prvalue, x( sizen=12 bipn_eu100=76.2 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10   prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08) 
prvalue, x( sizen=15 bipn_eu100=76.2 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10   prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08) 
prvalue, x( sizen=25 bipn_eu100=76.2 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10   prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08 ) 

prvalue, x(sizen=9) rest(median)
prvalue, x(sizen=10  ) rest(median) 
prvalue, x(sizen=12 ) rest(median)
prvalue, x(sizen=15) rest(median)
prvalue, x(sizen=25 ) rest(median)

prvalue, x(sizen=9 bipn_eu100=40.7  expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9   prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15 ) 
prvalue, x( sizen=10 bipn_eu100=40.7  expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9  prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 
prvalue, x( sizen=12 bipn_eu100=40.7  expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9   prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 
prvalue, x( sizen=15 bipn_eu100=40.7 expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9   prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 
prvalue, x(sizen=25 bipn_eu100=40.7 expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9  prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 

prvalue, x(sizen=9 bipn_eu100=min polityivnew=min concur=min majority_per_policy=0) rest(max)
prvalue, x(sizen=10   bipn_eu100=min polityivnew=min concur=min majority_per_policy=0) rest(max) 
prvalue, x(sizen=12  bipn_eu100=min polityivnew=min concur=min majority_per_policy=0) rest(max)
prvalue, x(sizen=15 bipn_eu100=min polityivnew=min concur=min majority_per_policy=0) rest(max)
prvalue, x(sizen=25  bipn_eu100=min polityivnew=min concur=min majority_per_policy=0) rest(max)

/*Demand for Discrimination*/

prvalue, x( demdisdum=0 bipn_eu100=max polityivnew=max concur=max majority_per_policy=1) rest(min)
prvalue, x( demdisdum=1 bipn_eu100=max  polityivnew=max concur=max majority_per_policy=1) rest(min) 

prvalue, x(demdisdum=0 sizen=10 bipn_eu100=76.2 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10   prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08 ) 
prvalue, x( demdisdum=1 sizen=10  bipn_eu100=76.2 expbip=0.326 concur=0.18 ceiling=1.14 majority_per_policy=1 polityivnew=10   prefdependency=0 rivalry=0 contribution=1.4 perccouncil_change=-2.08 ) 

prvalue, x(demdisdum=0 sizen=12) rest(median)
prvalue, x(demdisdum=1  sizen=12) rest(median) 

prvalue, x(demdisdum=0 sizen=15 bipn_eu100=40.7  expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9   prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15 ) 
prvalue, x(demdisdum=1 sizen=15 bipn_eu100=40.7  expbip=3.509 concur=0.1 ceiling=1.27 majority_per_policy=0 polityivnew=9  prefdependency=1 rivalry=1 contribution=14.4 perccouncil_change=-1.15) 

prvalue, x(demdisdum=0 bipn_eu100=min polityivnew=min concur=min majority_per_policy=0) rest(max)
prvalue, x(demdisdum=1   bipn_eu100=min polityivnew=min concur=min majority_per_policy=0) rest(max) 

log close
exit
